@@ -1,7 +1,7 @@
 /*****************************************************************************\
  *  $Id: genders_parsing.c,v 1.37 2010-02-02 00:04:34 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2010 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2011 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2001-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Jim Garlick <garlick@llnl.gov> and Albert Chu <chu11@llnl.gov>.
@@ -551,6 +551,7 @@ _parse_line(genders_t handle,
 	}
     }
   
+#ifndef WITH_NON_SHORTENED_HOSTNAMES
   if (strchr(nodenames, '.')) 
     {
       if (line_num > 0) 
@@ -561,6 +562,7 @@ _parse_line(genders_t handle,
       handle->errnum = GENDERS_ERR_PARSE;
       goto cleanup;
     }
+#endif /* !WITH_NON_SHORTENED_HOSTNAMES */
 
   __hostlist_create(hl, nodenames);
   __hostlist_iterator_create(hlitr, hl);
